<?php

// array where all configuration settings are stored.
$config=array();

// enable or disable debugging 
$config["system"]["debug"]      = TRUE; // TRUE for debugging.. FALSE for production environments.

if($config["system"]["debug"]){
	ini_set("error_reporting",E_ALL);
}else{
	ini_set("error_reporting",0);
}

// File Directory Settings 
// paths to directories where project and local backup files are stored
// do not forget the trailing slash!
// do not use "..", use absolute path instead.

$config["dir"]["files"] = "files/";
$config["dir"]["backups"] = "backups/";
// this for creating temporary files during PDF previews
// or while processing email attachments
// keep this value pointed to system tmp directory
$config["dir"]["temp"] = "/tmp";

// Database Connection Settings 

// msql,mssql,oci8,pgsql,mysql,etc. go to pear.php.net/db for detailed info
$config["database"]["system"] = "mysql";
// host name, this is usually localhost. 
$config["database"]["host"]   = "localhost";
// database name
$config["database"]["name"]   = "kiwi";
// database prefix
$config["database"]["prefix"]   = "kiwi_";
// database user, make sure this user has limited priviliges... 
$config["database"]["user"]   = "";
// database user password
$config["database"]["pass"]   = "";

// System Settings 

// enable or disable ssl 
$config["system"]["ssl"] = FALSE;
// path to Kiwi Manager.. do not exclude http (or https if ssl is enabled) and the trailing slash 
$config["system"]["domain"] = "http://www.yourdomain.com/kiwimanager/";
// off days for tasks. used on gantt. 0 (sunday) to 6 (saturday) 
$config["system"]["off"] = array(0,6);
// login key.. do not forget to change this setting to a different one Ex: md5('myownkey') 
$config["system"]["key"] = md5($config["system"]["domain"]."your own key");
// system title. 
$config["system"]["title"] = "Kiwi Manager";
// number of records displayed on paginated lists 
$config["system"]["offset"] = 25;
// number of items displayed on history dropdown 
$config["system"]["history"] = 15;
// number of items displayed in the activity section on the dashboard
$config["system"]["activity"] = 10;
// breadcrumb navigation separator
$config["system"]["separator"] = " » ";
// number of failed attempts after which login is disabled for 5 minutes
$config["system"]["attempt"] = 5;
// number of hours after which new item notices are disabled 
$config["system"]["notice"] = 25;
// TRUE to enable pdf previews. For linux systems only. Ghostscript (gs) must be installed.
$config["system"]["pdf"] = FALSE;

// FTP Backup - these values are presented as default values in the backup form

// ftp backup server
$config["system"]["backup_ftp_server"] = "";
// ftp port
$config["system"]["backup_ftp_port"] = 21;
// ftp directory to upload the backup file to
$config["system"]["backup_ftp_directory"] = "/";
// ftp account username
$config["system"]["backup_ftp_user"] = "";
// ftp account password
$config["system"]["backup_ftp_pass"] = "";
// active or passive ftp connection? active | passive (Passive is recommended behind firewalls)
$config["system"]["backup_ftp_conntype"] = "";

// Formatting 

// custom date display - see www.php.net/date for formatting options 
$config["format"]["date"] = "M d";
$config["format"]["date_detailed"] = "M d - H:i";
$config["format"]["date_calendar"] = "l d F Y";

// Company Information 

$config["company"]["name"] = "Your Company Name";
$config["company"]["email"] = "info@yourcompany.com";

// Notification settings

// this is the email addres set up specifically for the cron job to process
$config["notification"]["address"] = "kiwi@yourcompany.com";
// see php.net/imap_open for available formats
$config["notification"]["mailbox"] = "{localhost:110/pop3/notls}INBOX";
// mailbox username
$config["notification"]["username"] = "kiwi@yourcompany.com";
// mailbox password
$config["notification"]["password"] = '';
// imap connection options. see php.net/imap_open, you can leave it empty
$config["notification"]["options"] = '';
// max size of files that can be attached to emails in BYTES
// this setting is important... files larger than this size are not
// attached to notification emails. In addition, the system also rejects
// files larger than this setting sent to $config["notification"]["address"]
$config["notification"]["max_file_size"] = 512000; // 500kb
// notify sender after successfully processing an email?
$config["notification"]["send_success"] = FALSE;
// notify sender after an email processing failure?
$config["notification"]["send_failure"] = TRUE;

// Do NOT modify anything below this line unless you know what you are doing! 

// PHP Settings 

ini_set("include_path",".".PATH_SEPARATOR."./includes/pear");
ini_set("session.use_cookies",1); // use cookies to store session ids. do not change!
ini_set("session.use_only_cookies",1); // use only cookies to store session ids. do not change!
ini_set("session.cookie_lifetime",0); // specifies the lifetime of the cookie in seconds. 0 means cookie expires when browser window is closed.
ini_set("session.use_trans_sid",0); // transparent sid support. keep it disabled!
ini_set("session.cache_limiter","nocache"); // do not cache pages. keep it nocache!
ini_set("session.gc_maxlifetime",14400); // number of seconds after which a session is seen as garbage..
ini_set("arg_separator.output","&amp;"); // for xhtml compatibility

define("VALID_INCLUDE","Burak The Developer");

if(!empty($_COOKIE["language"])){
	$language  = preg_replace("/[^a-z]/i","",$_COOKIE["language"]);
	if(file_exists("language/".$language.".php")){
		require_once "language/".$language.".php";
	}else{
		require_once "language/en.php";
	}
}else{
	require_once "language/en.php";
}

// default page encoding 
$config["system"]["encoding"] = defined(_LANGUAGE_ENCODING) ? _LANGUAGE_ENCODING : "utf-8";

require_once "library/pattern.lib.php";
require_once "library/data.lib.php";
require_once "library/date.lib.php";
require_once "library/registry.lib.php";
require_once "library/controller.lib.php";
require_once "library/error.lib.php";
require_once "library/database.lib.php";
require_once "library/element.lib.php";
require_once "library/form.lib.php";
require_once "library/list.lib.php";
require_once "library/mail.lib.php";
require_once "library/helper.lib.php";

?>